@@ -7,4 +7,8 @@
 #' @export
 is.gifti = function(x) {
   inherits(x, "gifti")
-}
\ No newline at end of file
+}
+
+#' @export
+#' @rdname is.gifti
+is_gifti = is.gifti
\ No newline at end of file
